@@ -1,6 +1,6 @@
 package Statocles::App::Perldoc;
 # ABSTRACT: Render documentation for Perl modules
-$Statocles::App::Perldoc::VERSION = '0.060';
+$Statocles::App::Perldoc::VERSION = '0.061';
 use Statocles::Base 'Class';
 use Statocles::Page::Plain;
 use Scalar::Util qw( blessed );
@@ -137,6 +137,7 @@ sub pages {
         my %page_args = (
             layout => $self->site->theme->template( site => 'layout.html' ),
             template => $self->site->theme->template( perldoc => 'pod.html' ),
+            title => $module,
             content => "$dom",
             app => $self,
             path => $self->_module_href( $module ),
@@ -158,6 +159,7 @@ sub pages {
             path => $source_path,
             layout => $self->site->theme->template( site => 'layout.html' ),
             template => $self->site->theme->template( perldoc => 'source.html' ),
+            title => "$module (source)",
             content => Path::Tiny->new( $path )->slurp,
             app => $self,
             data => {
@@ -273,7 +275,7 @@ Statocles::App::Perldoc - Render documentation for Perl modules
 
 =head1 VERSION
 
-version 0.060
+version 0.061
 
 =head1 DESCRIPTION
 
