@@ -1,6 +1,6 @@
 package Statocles::Deploy;
 # ABSTRACT: Base role for ways to deploy a site
-$Statocles::Deploy::VERSION = '0.060';
+$Statocles::Deploy::VERSION = '0.061';
 use Statocles::Base 'Role';
 
 
@@ -10,6 +10,12 @@ has base_url => (
 );
 
 
+has site => (
+    is => 'rw',
+    isa => InstanceOf['Statocles::Site'],
+);
+
+
 requires qw( deploy );
 
 1;
@@ -24,7 +30,7 @@ Statocles::Deploy - Base role for ways to deploy a site
 
 =head1 VERSION
 
-version 0.060
+version 0.061
 
 =head1 DESCRIPTION
 
@@ -41,6 +47,11 @@ based on this URL.
 This allows you to have different versions of the site deployed to different
 URLs.
 
+=head2 site
+
+The site this deploy is deploying for. This will be set before the site calls
+L<the deploy method|/deploy>.
+
 =head1 METHODS
 
 =head2 deploy
