@@ -1,6 +1,6 @@
 package Statocles::Deploy::File;
 # ABSTRACT: Deploy a site to a folder on the filesystem
-$Statocles::Deploy::File::VERSION = '0.060';
+$Statocles::Deploy::File::VERSION = '0.061';
 use Statocles::Base 'Class';
 with 'Statocles::Deploy';
 
@@ -24,18 +24,13 @@ sub deploy {
         $_->remove_tree for $self->path->children;
     }
 
+    $self->site->log->info( "Copying files from build dir to deploy dir" );
     my @files;
     my $iter = $from_store->find_files( include_documents => 1 );
     while ( my $path = $iter->() ) {
         # Git versions before 1.7.4.1 require a relative path to 'git add'
         push @files, $path->relative( "/" )->stringify;
-
-        # XXX Implement a friendlier way to copy files from Stores
-        my $in_fh = $from_store->open_file( $path );
-        my $out_fh = $self->path->child( $path )->touchpath->openw_raw;
-        while ( my $line = <$in_fh> ) {
-            $out_fh->print( $line );
-        }
+        $from_store->path->child( $path )->copy( $self->path->child( $path )->touchpath );
     }
 
     return @files;
@@ -53,7 +48,7 @@ Statocles::Deploy::File - Deploy a site to a folder on the filesystem
 
 =head1 VERSION
 
-version 0.060
+version 0.061
 
 =head1 DESCRIPTION
 
