@@ -1,7 +1,8 @@
 package Statocles::Document;
 # ABSTRACT: Base class for all Statocles documents
-$Statocles::Document::VERSION = '0.060';
+$Statocles::Document::VERSION = '0.061';
 use Statocles::Base 'Class';
+use Statocles::Image;
 
 
 has path => (
@@ -51,6 +52,27 @@ has links => (
 );
 
 
+has images => (
+    is => 'ro',
+    isa => HashRef[InstanceOf['Statocles::Image']],
+    default => sub { +{} },
+    coerce => sub {
+        my ( $ref ) = @_;
+        my %img;
+        for my $name ( keys %$ref ) {
+            my $attrs = $ref->{ $name };
+            if ( !ref $attrs ) {
+                $attrs = { src => $attrs };
+            }
+            $img{ $name } = Statocles::Image->new(
+                %{ $attrs },
+            );
+        }
+        return \%img;
+    },
+);
+
+
 has date => (
     is => 'rw',
     isa => InstanceOf['Time::Piece'],
@@ -96,7 +118,7 @@ Statocles::Document - Base class for all Statocles documents
 
 =head1 VERSION
 
-version 0.060
+version 0.061
 
 =head1 DESCRIPTION
 
@@ -207,6 +229,36 @@ The text of the link. Not needed for stylesheet or script links.
 
 =back
 
+=head2 images
+
+    ---
+    images:
+        title:
+            src: title.jpg
+            alt: A title image for this post
+        banner: banner.jpg
+    ---
+
+Related images for this document. These are used by themes to display
+images in appropriate templates. Each image has a category, like C<title>,
+C<banner>, or C<thumbnail>, mapped to an L<image object|Statocles::Image>.
+See the L<Statocles::Image|Statocles::Image> documentation for a full
+list of supported attributes. The most common attributes are:
+
+=over 4
+
+=item src
+
+The source path of the image. Relative paths will be resolved relative
+to this document.
+
+=item alt
+
+The alternative text to display if the image cannot be downloaded or
+rendered. Also the text to use for non-visual media.
+
+=back
+
 =head2 date
 
     ---
