@@ -1,6 +1,6 @@
 package Statocles::Page;
 # ABSTRACT: Base class for rendering objects
-$Statocles::Page::VERSION = '0.060';
+$Statocles::Page::VERSION = '0.061';
 use Statocles::Base 'Role';
 use Statocles::Template;
 
@@ -30,6 +30,7 @@ has path => (
 has title => (
     is => 'rw',
     isa => Str,
+    default => '',
 );
 
 
@@ -89,6 +90,15 @@ has _links => (
 );
 
 
+has _images => (
+    is => 'ro',
+    isa => HashRef[InstanceOf['Statocles::Image']],
+    lazy => 1,
+    default => sub { +{} },
+    init_arg => 'images',
+);
+
+
 has markdown => (
     is => 'rw',
     isa => HasMethods['markdown'],
@@ -179,6 +189,16 @@ sub links {
 }
 
 
+sub images {
+    my ( $self, $name ) = @_;
+    # This exists here as a placeholder in case we ever need to handle
+    # arrays of images, which I anticipate will happen when we build
+    # image galleries or want to be able to pick a single random image
+    # from an array.
+    return $self->_images->{ $name };
+}
+
+
 sub basename {
     my ( $self ) = @_;
     return $self->path->basename;
@@ -202,7 +222,7 @@ Statocles::Page - Base class for rendering objects
 
 =head1 VERSION
 
-version 0.060
+version 0.061
 
 =head1 DESCRIPTION
 
@@ -255,6 +275,12 @@ attributes are:
     href        - The page for the link
     type        - The MIME type of the link, optional
 
+=head2 images
+
+A hash of images related to this page. Each value should be an L<image
+object|Statocles::Image>.  These are used by themes to show images next
+to articles, thumbnails, and/or shortcut icons.
+
 =head2 markdown
 
 The markdown object to render document Markdown. Defaults to L<the markdown
@@ -333,6 +359,13 @@ Get the links set for the given key. See L<the links attribute|/links> for some
 commonly-used keys. Returns a list of L<link objects|Statocles::Link>. In
 scalar context, returns the first link in the list.
 
+=head2 images
+
+    my $image = $page->images( $key );
+
+Get the images for the given key. See L<the images attribute|/images> for some
+commonly-used keys. Returns an L<image object|Statocles::Image>.
+
 =head2 basename
 
     my $name = $page->basename;
