@@ -1,6 +1,6 @@
 package Statocles::Page::Document;
 # ABSTRACT: Render document objects into HTML
-$Statocles::Page::Document::VERSION = '0.060';
+$Statocles::Page::Document::VERSION = '0.061';
 use Statocles::Base 'Class';
 with 'Statocles::Page';
 use Statocles::Template;
@@ -48,6 +48,11 @@ has '+_links' => (
     default => sub { $_[0]->document->links },
 );
 
+has '+_images' => (
+    default => sub { $_[0]->document->images },
+);
+
+
 sub _render_content_template {
     my ( $self, $content, $vars ) = @_;
     my $tmpl = $self->site->theme->build_template( $self->path, $content );
@@ -135,7 +140,7 @@ Statocles::Page::Document - Render document objects into HTML
 
 =head1 VERSION
 
-version 0.060
+version 0.061
 
 =head1 DESCRIPTION
 
