@@ -1,9 +1,9 @@
 package Statocles::Plugin::HTMLLint;
 # ABSTRACT: Check HTML for common errors and issues
-$Statocles::Plugin::HTMLLint::VERSION = '0.060';
+$Statocles::Plugin::HTMLLint::VERSION = '0.061';
 use Statocles::Base 'Class';
 BEGIN {
-    eval { require HTML::Lint::Pluggable; 1 }
+    eval { require HTML::Lint::Pluggable; HTML::Lint::Pluggable->VERSION( 0.06 ); 1 }
         or die "Error loading Statocles::Plugin::HTMLLint. To use this plugin, install HTML::Lint::Pluggable";
 };
 
@@ -51,7 +51,7 @@ Statocles::Plugin::HTMLLint - Check HTML for common errors and issues
 
 =head1 VERSION
 
-version 0.060
+version 0.061
 
 =head1 SYNOPSIS
 
