@@ -1,6 +1,6 @@
 package Statocles::Store;
 # ABSTRACT: The source for data documents and files
-$Statocles::Store::VERSION = '0.060';
+$Statocles::Store::VERSION = '0.061';
 use Statocles::Base 'Class';
 use Scalar::Util qw( weaken blessed );
 use Statocles::Document;
@@ -204,9 +204,9 @@ sub _freeze_document {
     if ( exists $doc->{date} ) {
         $doc->{date} = $doc->{date}->strftime( $DATETIME_FORMAT );
     }
-    if ( exists $doc->{links} ) {
-        if ( !keys %{ $doc->{links} } ) {
-            delete $doc->{links};
+    for my $hash_type ( qw( links images ) ) {
+        if ( exists $doc->{ $hash_type } && !keys %{ $doc->{ $hash_type } } ) {
+            delete $doc->{ $hash_type };
         }
     }
     return $doc;
@@ -296,7 +296,7 @@ Statocles::Store - The source for data documents and files
 
 =head1 VERSION
 
-version 0.060
+version 0.061
 
 =head1 DESCRIPTION
 
