@@ -1,6 +1,6 @@
 package Statocles::Test;
 # ABSTRACT: Common test routines for Statocles
-$Statocles::Test::VERSION = '0.060';
+$Statocles::Test::VERSION = '0.061';
 use Statocles::Base;
 use Test::More;
 use Test::Exception;
@@ -30,10 +30,19 @@ sub build_test_site {
                 : Path::Tiny->tempdir
                 ;
 
+    # Give a testable logger by default, but only if we haven't asked
+    # for some verbose logging from the environment
+    my $log     = $site_args{log}
+                || Mojo::Log->new(
+                    level => 'warn',
+                    max_history_size => 500,
+                );
+
     return Statocles::Site->new(
         title => 'Example Site',
         build_store => $store,
         deploy => $deploy,
+        log => $log,
         %site_args,
     );
 }
@@ -303,7 +312,7 @@ Statocles::Test - Common test routines for Statocles
 
 =head1 VERSION
 
-version 0.060
+version 0.061
 
 =head1 DESCRIPTION
 
